@@ -14,8 +14,7 @@ use open ':std', ':encoding(UTF-8)'; # force stdin, stdout, stderr into utf8
 use JSON::PP ();
 use constant { true => JSON::PP::true, false => JSON::PP::false };
 
-use JSON::MaybeXS;
-my $encoder = JSON::MaybeXS->new(allow_nonref => 1, utf8 => 0);
+my $encoder = (Mojo::JSON::JSON_XS ? 'Cpanel::JSON::XS' : 'JSON::PP')->new->allow_nonref(1)->utf8(0);
 
 # like sprintf, but all list items are JSON-encoded. assumes placeholders are %s!
 sub json_sprintf {
